@@ -22,21 +22,26 @@ class Edge:
     def to_dict(self, pick_by_predicate: Optional[Callable[[Any], bool]] = is_not_none) -> Dict[str, Any]:
         node_ids = self.node_ids
 
-        dct = {
-            k: v
-            for k, v in {
+        field_dict: Dict[str, Any] = {}
+        field_dict.update(
+            {
                 "node_ids": node_ids,
-            }.items()
-            if v != UNSET
-        }
+            }
+        )
+
+        field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
-            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
-        return dct
+            field_dict = {k: v for k, v in field_dict.items() if pick_by_predicate(v)}
+
+        return field_dict
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "Edge":
-        node_ids = cast(List[int], d["node_ids"])
+    def from_dict(src_dict: Dict[str, Any]) -> "Edge":
+        d = src_dict.copy()
+        node_ids = cast(List[int], d.pop("node_ids"))
 
-        return Edge(
+        edge = Edge(
             node_ids=node_ids,
         )
+
+        return edge
