@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, List, Optional, cast
 import attr
 
 from ..models.characteristic import Characteristic
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -22,26 +23,35 @@ class OperationSite:
 
         node_ids = self.node_ids
 
-        dct = {
-            "characteristics": characteristics,
-            "node_ids": node_ids,
-        }
+        field_dict: Dict[str, Any] = {}
+        field_dict.update(
+            {
+                "characteristics": characteristics,
+                "node_ids": node_ids,
+            }
+        )
+
+        field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
-            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
-        return dct
+            field_dict = {k: v for k, v in field_dict.items() if pick_by_predicate(v)}
+
+        return field_dict
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "OperationSite":
+    def from_dict(src_dict: Dict[str, Any]) -> "OperationSite":
+        d = src_dict.copy()
         characteristics = []
-        _characteristics = d["characteristics"]
+        _characteristics = d.pop("characteristics")
         for characteristics_item_data in _characteristics:
             characteristics_item = Characteristic.from_dict(characteristics_item_data)
 
             characteristics.append(characteristics_item)
 
-        node_ids = cast(List[int], d["node_ids"])
+        node_ids = cast(List[int], d.pop("node_ids"))
 
-        return OperationSite(
+        operation_site = OperationSite(
             characteristics=characteristics,
             node_ids=node_ids,
         )
+
+        return operation_site
